@@ -894,6 +894,11 @@ main (int argc, char *argv[])
 	g_io_add_watch (master_io, G_IO_IN, handle_new_client, NULL);
 	g_io_channel_unref (master_io);
 
+	/* Don't hold up the cwd, allowing unmounts of e.g. /home
+	 * since we run a while after logout.
+	 */
+	chdir ("/");
+
 	loop = g_main_loop_new (NULL, TRUE);
 
 	g_timeout_add (5000, &cleanup_timeout, NULL);
